==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/KikChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.KikChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Kik channel.
 * @property apiKey Kik API key. Value only returned through POST to the action Channel List API, otherwise empty.
 * @property isEnabled Whether this channel is enabled for the bot
 * @property isValidated Whether this channel is validated for the bot
 * @property userName The Kik user name
 */
public data class KikChannelPropertiesArgs(
    public val apiKey: Output<String>? = null,
    public val isEnabled: Output<Boolean>,
    public val isValidated: Output<Boolean>? = null,
    public val userName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.KikChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.KikChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.KikChannelPropertiesArgs.builder()
            .apiKey(apiKey?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .isValidated(isValidated?.applyValue({ args0 -> args0 }))
            .userName(userName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KikChannelPropertiesArgs].
 */
@PulumiTagMarker
public class KikChannelPropertiesArgsBuilder internal constructor() {
    private var apiKey: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    private var isValidated: Output<Boolean>? = null

    private var userName: Output<String>? = null

    /**
     * @param value Kik API key. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("clthsbpnihohmpkm")
    public suspend fun apiKey(`value`: Output<String>) {
        this.apiKey = value
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("tyruqvbwxvkmwghw")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Whether this channel is validated for the bot
     */
    @JvmName("spcqaodsiefmwttj")
    public suspend fun isValidated(`value`: Output<Boolean>) {
        this.isValidated = value
    }

    /**
     * @param value The Kik user name
     */
    @JvmName("bprgsiugehdfmhau")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value Kik API key. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("myhfbeogtieycrsp")
    public suspend fun apiKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiKey = mapped
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("ivmhhpbnxljtfrak")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value Whether this channel is validated for the bot
     */
    @JvmName("wgcvrganfxglqlox")
    public suspend fun isValidated(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isValidated = mapped
    }

    /**
     * @param value The Kik user name
     */
    @JvmName("jvsgrkuficbrhlyr")
    public suspend fun userName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): KikChannelPropertiesArgs = KikChannelPropertiesArgs(
        apiKey = apiKey,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        isValidated = isValidated,
        userName = userName ?: throw PulumiNullFieldException("userName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/KikChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.KikChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Kik channel.
 * @property apiKey Kik API key. Value only returned through POST to the action Channel List API, otherwise empty.
 * @property isEnabled Whether this channel is enabled for the bot
 * @property isValidated Whether this channel is validated for the bot
 * @property userName The Kik user name
 */
public data class KikChannelPropertiesArgs(
    public val apiKey: Output<String>? = null,
    public val isEnabled: Output<Boolean>,
    public val isValidated: Output<Boolean>? = null,
    public val userName: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.KikChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.KikChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.KikChannelPropertiesArgs.builder()
            .apiKey(apiKey?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled.applyValue({ args0 -> args0 }))
            .isValidated(isValidated?.applyValue({ args0 -> args0 }))
            .userName(userName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KikChannelPropertiesArgs].
 */
@PulumiTagMarker
public class KikChannelPropertiesArgsBuilder internal constructor() {
    private var apiKey: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    private var isValidated: Output<Boolean>? = null

    private var userName: Output<String>? = null

    /**
     * @param value Kik API key. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("ugakbtdidahwoiam")
    public suspend fun apiKey(`value`: Output<String>) {
        this.apiKey = value
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("ljktaorddabioxhj")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value Whether this channel is validated for the bot
     */
    @JvmName("jtvxocxcktxxijwk")
    public suspend fun isValidated(`value`: Output<Boolean>) {
        this.isValidated = value
    }

    /**
     * @param value The Kik user name
     */
    @JvmName("xjieoonniinwpeye")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value Kik API key. Value only returned through POST to the action Channel List API, otherwise empty.
     */
    @JvmName("qxqywleagykklewp")
    public suspend fun apiKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiKey = mapped
    }

    /**
     * @param value Whether this channel is enabled for the bot
     */
    @JvmName("lujcruarhoucckra")
    public suspend fun isEnabled(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value Whether this channel is validated for the bot
     */
    @JvmName("pvbsmhnvisvtutiw")
    public suspend fun isValidated(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isValidated = mapped
    }

    /**
     * @param value The Kik user name
     */
    @JvmName("oetljcnbujsiytcf")
    public suspend fun userName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): KikChannelPropertiesArgs = KikChannelPropertiesArgs(
        apiKey = apiKey,
        isEnabled = isEnabled ?: throw PulumiNullFieldException("isEnabled"),
        isValidated = isValidated,
        userName = userName ?: throw PulumiNullFieldException("userName"),
    )
}
